@@ -5,7 +5,7 @@ use warnings;
 package MooX::Press;
 
 our $AUTHORITY = 'cpan:TOBYINK';
-our $VERSION   = '0.001';
+our $VERSION   = '0.002';
 
 use Exporter::Tiny qw(mkopt);
 use Scalar::Util qw(blessed);
@@ -19,7 +19,7 @@ my $_expand = sub {
 };
 
 my $_merge = sub {
-	map defined&&!ref ? $_ : $_expand->($_), @_;
+	map defined($_)&&!ref($_) ? $_ : $_expand->($_), @_;
 };
 
 my $_expand_simple = sub {
